@@ -66,10 +66,12 @@ UTIL_NAME = "pairtools_dedup"
     type=str,
     default="",
     help="output file for duplicate statistics."
-    " If file exists, it will be open in the append mode."
-    " If the path ends with .gz or .lz4, the output is bgzip-/lz4c-compressed."
-    " By default, by-tile duplicate statistics are not printed."
-    " Note that the readID should be provided and contain tile information for this option. ",
+    " Note that the readID should be provided and contain tile information for this option. "
+    " This analysis is possible when pairtools is run on a dataset with original Illumina-generated read IDs, "
+    " because SRA does not store original read IDs from the sequencer. "
+    " By default, by-tile duplicate statistics are not printed. "
+    " If file exists, it will be open in the append mode. "
+    " If the path ends with .gz or .lz4, the output is bgzip-/lz4c-compressed.",
 )
 
 ### Set the dedup method:
@@ -169,12 +171,6 @@ UTIL_NAME = "pairtools_dedup"
     help=r"Separator (\t, \v, etc. characters are "
     "supported, pass them in quotes). [input format option]",
 )
-@click.option(
-    "--comment-char",
-    type=str,
-    default="#",
-    help="The first character of comment lines. [input format option]",
-)
 @click.option(
     "--send-header-to",
     type=click.Choice(["dups", "dedup", "both", "none"]),
@@ -302,7 +298,6 @@ def dedup(
     max_mismatch,
     method,
     sep,
-    comment_char,
     send_header_to,
     c1,
     c2,
@@ -320,7 +315,7 @@ def dedup(
 ):
     """Find and remove PCR/optical duplicates.
 
-    Find PCR duplicates in an upper-triangular flipped sorted pairs/pairsam
+    Find PCR/optical duplicates in an upper-triangular flipped sorted pairs/pairsam
     file. Allow for a +/-N bp mismatch at each side of duplicated molecules.
 
     PAIRS_PATH : input triu-flipped sorted .pairs or .pairsam file.  If the
@@ -340,7 +335,6 @@ def dedup(
         max_mismatch,
         method,
         sep,
-        comment_char,
         send_header_to,
         c1,
         c2,
@@ -374,7 +368,6 @@ def dedup_py(
     max_mismatch,
     method,
     sep,
-    comment_char,
     send_header_to,
     c1,
     c2,
@@ -546,7 +539,7 @@ def dedup_py(
         )
     elif backend in ("scipy", "sklearn"):
         streaming_dedup(
-            in_stream=instream,
+            in_stream=body_stream,
             colnames=column_names,
             chunksize=chunksize,
             carryover=carryover,
@@ -556,7 +549,6 @@ def dedup_py(
             extra_col_pairs=list(extra_col_pair),
             keep_parent_id=keep_parent_id,
             unmapped_chrom=unmapped_chrom,
-            comment_char=comment_char,
             outstream=outstream,
             outstream_dups=outstream_dups,
             outstream_unmapped=outstream_unmapped,
